@@ -3,11 +3,10 @@ pub(crate) use crate::pubgrub::distribution::PubGrubDistribution;
 pub(crate) use crate::pubgrub::package::{PubGrubPackage, PubGrubPackageInner, PubGrubPython};
 pub(crate) use crate::pubgrub::priority::{PubGrubPriorities, PubGrubPriority};
 pub(crate) use crate::pubgrub::report::PubGrubReportFormatter;
-pub use crate::pubgrub::specifier::{PubGrubSpecifier, PubGrubSpecifierError};
+pub use uv_pubgrub::{PubGrubSpecifier, PubGrubSpecifierError};
 
 mod dependencies;
 mod distribution;
 mod package;
 mod priority;
 mod report;
-mod specifier;
