@@ -56,7 +56,7 @@ impl ResolutionStrategy {
             ResolutionMode::LowestDirect => Self::LowestDirect(
                 manifest
                     .user_requirements(markers, dependencies)
-                    .map(|requirement| (*requirement).clone())
+                    .map(|requirement| requirement.name.clone())
                     .collect(),
             ),
         }
