@@ -150,6 +150,7 @@ pub struct ToolUv {
 
 #[derive(Serialize, Deserialize, OptionsMetadata, Default, Debug, Clone, PartialEq, Eq)]
 #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
+#[serde(rename_all = "kebab-case", deny_unknown_fields)]
 pub struct ToolUvWorkspace {
     /// Packages to include as workspace members.
     ///
@@ -206,7 +207,7 @@ impl Deref for SerdePattern {
 /// A `tool.uv.sources` value.
 #[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
-#[serde(untagged, deny_unknown_fields)]
+#[serde(rename_all = "kebab-case", untagged, deny_unknown_fields)]
 pub enum Source {
     /// A remote Git repository, available over HTTPS or SSH.
     ///
