@@ -3,13 +3,14 @@
 use anyhow::{anyhow, Context};
 use itertools::Itertools;
 use owo_colors::OwoColorize;
-use std::collections::BTreeSet;
+use std::collections::{BTreeSet, HashSet};
 use std::fmt::Write;
 use std::path::PathBuf;
 use tracing::debug;
 
 use distribution_types::{
-    CachedDist, Diagnostic, InstalledDist, ResolutionDiagnostic, UnresolvedRequirementSpecification,
+    CachedDist, Diagnostic, InstalledDist, LocalDist, ResolutionDiagnostic,
+    UnresolvedRequirementSpecification,
 };
 use distribution_types::{
     DistributionMetadata, IndexLocations, InstalledMetadata, Name, Resolution,
@@ -20,8 +21,7 @@ use pypi_types::Requirement;
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, RegistryClient};
 use uv_configuration::{
-    BuildOptions, Concurrency, Constraints, ExtrasSpecification, Overrides, PreviewMode, Reinstall,
-    Upgrade,
+    BuildOptions, Concurrency, Constraints, ExtrasSpecification, Overrides, Reinstall, Upgrade,
 };
 use uv_dispatch::BuildDispatch;
 use uv_distribution::DistributionDatabase;
@@ -110,7 +110,6 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
     options: Options,
     logger: Box<dyn ResolveLogger>,
     printer: Printer,
-    preview: PreviewMode,
 ) -> Result<ResolutionGraph, Error> {
     let start = std::time::Instant::now();
 
@@ -121,7 +120,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
             requirements,
             hasher,
             index,
-            DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+            DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
         )
         .with_reporter(ResolverReporter::from(printer))
         .resolve()
@@ -134,7 +133,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
                 extras,
                 hasher,
                 index,
-                DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+                DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
             )
             .with_reporter(ResolverReporter::from(printer))
             .resolve()
@@ -187,7 +186,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
         overrides,
         hasher,
         index,
-        DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+        DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
     )
     .with_reporter(ResolverReporter::from(printer))
     .resolve()
@@ -212,7 +211,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
                 &dev,
                 hasher,
                 index,
-                DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+                DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
             )
             .with_reporter(ResolverReporter::from(printer))
             .resolve(&markers)
@@ -258,7 +257,7 @@ pub(crate) async fn resolve<InstalledPackages: InstalledPackagesProvider>(
             hasher,
             build_dispatch,
             installed_packages,
-            DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+            DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
         )?
         .with_reporter(reporter);
 
@@ -289,17 +288,38 @@ pub(crate) enum Modifications {
 #[derive(Debug, Clone, Default)]
 pub(crate) struct Changelog {
     /// The distributions that were installed.
-    pub(crate) installed: Vec<CachedDist>,
+    pub(crate) installed: HashSet<LocalDist>,
     /// The distributions that were uninstalled.
-    pub(crate) uninstalled: Vec<InstalledDist>,
+    pub(crate) uninstalled: HashSet<LocalDist>,
+    /// The distributions that were reinstalled.
+    pub(crate) reinstalled: HashSet<LocalDist>,
 }
 
 impl Changelog {
+    /// Create a [`Changelog`] from a list of installed and uninstalled distributions.
+    pub(crate) fn new(installed: Vec<CachedDist>, uninstalled: Vec<InstalledDist>) -> Self {
+        let mut uninstalled: HashSet<_> = uninstalled.into_iter().map(LocalDist::from).collect();
+
+        let (reinstalled, installed): (HashSet<_>, HashSet<_>) = installed
+            .into_iter()
+            .map(LocalDist::from)
+            .partition(|dist| uninstalled.contains(dist));
+
+        uninstalled.retain(|dist| !reinstalled.contains(dist));
+
+        Self {
+            installed,
+            uninstalled,
+            reinstalled,
+        }
+    }
+
     /// Create a [`Changelog`] from a list of installed distributions.
     pub(crate) fn from_installed(installed: Vec<CachedDist>) -> Self {
         Self {
-            installed,
-            uninstalled: vec![],
+            installed: installed.into_iter().map(LocalDist::from).collect(),
+            uninstalled: HashSet::default(),
+            reinstalled: HashSet::default(),
         }
     }
 
@@ -339,7 +359,6 @@ pub(crate) async fn install(
     logger: Box<dyn InstallLogger>,
     dry_run: bool,
     printer: Printer,
-    preview: PreviewMode,
 ) -> Result<Changelog, Error> {
     let start = std::time::Instant::now();
 
@@ -407,7 +426,7 @@ pub(crate) async fn install(
             tags,
             hasher,
             build_options,
-            DistributionDatabase::new(client, build_dispatch, concurrency.downloads, preview),
+            DistributionDatabase::new(client, build_dispatch, concurrency.downloads),
         )
         .with_reporter(PrepareReporter::from(printer).with_length(remote.len() as u64));
 
@@ -474,10 +493,7 @@ pub(crate) async fn install(
     }
 
     // Construct a summary of the changes made to the environment.
-    let changelog = Changelog {
-        installed: installs,
-        uninstalled: uninstalls,
-    };
+    let changelog = Changelog::new(installs, uninstalls);
 
     // Notify the user of any environment modifications.
     logger.on_complete(&changelog, printer)?;
@@ -619,6 +635,15 @@ fn report_dry_run(
                     event.version.dimmed()
                 )?;
             }
+            ChangeEventKind::Reinstalled => {
+                writeln!(
+                    printer.stderr(),
+                    " {} {}{}",
+                    "~".yellow(),
+                    event.name.bold(),
+                    event.version.dimmed()
+                )?;
+            }
         }
     }
 
